@@ -37,13 +37,12 @@ public:
     ~MainWidget();
 
 private Q_SLOTS:
-    void createSearch();
     void startServer();
     void stopServer();
     void restartServer();
 
 private:
-    BrowserWidget *mBrowser;
+    BrowserWidget *mBrowser = nullptr;
 };
 
 #endif
